"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.signRequestObject = void 0;
const n8n_workflow_1 = require("n8n-workflow");
const client_oauth2_1 = __importDefault(require("client-oauth2"));
async function signRequestObject(iExecuteFunctions, requestObject, credentials) {
    const oAuthClient = new client_oauth2_1.default({
        clientId: credentials.clientId,
        clientSecret: credentials.clientSecret,
        accessTokenUri: credentials.accessTokenUrl,
        scopes: credentials.scope.split(' '),
    });
    const oauthTokenData = credentials.oauthTokenData;
    const token = oAuthClient.createToken(await getAccessToken(iExecuteFunctions, credentials), oauthTokenData.refreshToken, oauthTokenData.tokenType, oauthTokenData);
    return token.sign(requestObject);
}
exports.signRequestObject = signRequestObject;
async function getAccessToken(iExecuteFunctions, credentials) {
    const BASE_URL = 'https://biz-oauth.yahoo.co.jp/oauth/v1/token';
    const oauthTokenData = credentials.oauthTokenData;
    const qs = {
        grant_type: 'refresh_token',
        client_id: credentials.clientId,
        client_secret: credentials.clientSecret,
        refresh_token: oauthTokenData.refresh_token,
    };
    const queryStringElements = [];
    for (const key of Object.keys(qs)) {
        queryStringElements.push(`${key}=${qs[key]}`);
    }
    const options = {
        uri: `${BASE_URL}?${queryStringElements.join('&')}`,
        json: true,
    };
    try {
        const response = await iExecuteFunctions.helpers.request(options);
        return response.access_token;
    }
    catch (e) {
        console.log(e);
        throw new n8n_workflow_1.WorkflowOperationError('Failed to refresh Yahoo Jp token, please reconnect the app.');
    }
}
//# sourceMappingURL=GenericFunctions.js.map