"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.YahooJpAds = void 0;
const n8n_workflow_1 = require("n8n-workflow");
const axios_1 = __importDefault(require("axios"));
const form_data_1 = __importDefault(require("form-data"));
const GenericFunctions_1 = require("./GenericFunctions");
class YahooJpAds {
    constructor() {
        this.description = {
            displayName: 'Yahoo Japan Ads',
            name: 'yahooJpAds',
            icon: 'file:yahoo.svg',
            group: ['transform'],
            version: 1,
            subtitle: '={{$parameter["resource"]}}',
            description: 'Operations on Yahoo! JAPAN Ads',
            defaults: {
                name: 'Yahoo Japan Ads',
            },
            inputs: ['main'],
            outputs: ['main'],
            credentials: [
                {
                    name: 'yahooJpAdsOAuth2Api',
                    required: true,
                },
            ],
            properties: [
                {
                    displayName: 'Resource',
                    name: 'resource',
                    type: 'options',
                    noDataExpression: true,
                    options: [
                        {
                            name: 'Upload Offline Conversion',
                            value: 'uploadOfflineConversion',
                        },
                    ],
                    default: 'uploadOfflineConversion',
                },
                {
                    displayName: 'Account ID',
                    name: 'accountId',
                    type: 'string',
                    displayOptions: {
                        show: {
                            resource: ['uploadOfflineConversion'],
                        },
                    },
                    default: '',
                },
                {
                    displayName: 'Upload File Name',
                    name: 'uploadFileName',
                    type: 'string',
                    displayOptions: {
                        show: {
                            resource: ['uploadOfflineConversion'],
                        },
                    },
                    default: '',
                },
                {
                    displayName: 'Binary Property',
                    name: 'binaryPropertyName',
                    type: 'string',
                    required: true,
                    default: 'data',
                    displayOptions: {
                        show: {
                            resource: ['uploadOfflineConversion'],
                        },
                    },
                    description: 'Name of the binary property which contains the data for the file to be uploaded',
                },
            ],
        };
    }
    async execute() {
        const item = this.getInputData()[0];
        const returnData = [];
        const BASE_URL = 'https://ads-search.yahooapis.jp/api/v8';
        try {
            const resource = this.getNodeParameter('resource', 0);
            if (resource === 'uploadOfflineConversion') {
                const qs = {
                    accountId: this.getNodeParameter('accountId', 0),
                    uploadType: 'NEW',
                    uploadFileName: this.getNodeParameter('uploadFileName', 0),
                };
                const queryStringElements = [];
                for (const key of Object.keys(qs)) {
                    queryStringElements.push(`${key}=${qs[key]}`);
                }
                const URL = `${BASE_URL}/OfflineConversionService/upload?${queryStringElements.join('&')}`;
                const binaryPropertyName = this.getNodeParameter('binaryPropertyName', 0);
                if (item.binary === undefined || item.binary[binaryPropertyName] === undefined) {
                    throw new n8n_workflow_1.NodeOperationError(this.getNode(), `No binary data property "${binaryPropertyName}" does not exists on item!`);
                }
                const binaryDataBuffer = await this.helpers.getBinaryDataBuffer(0, binaryPropertyName);
                const formData = new form_data_1.default();
                formData.append('file', binaryDataBuffer);
                const credentials = await this.getCredentials('yahooJpAdsOAuth2Api');
                const signedRequestObject = await (0, GenericFunctions_1.signRequestObject)(this, { headers: formData.getHeaders() }, credentials);
                const response = await axios_1.default.post(URL, formData, signedRequestObject);
                returnData.push({ json: response.data });
            }
        }
        catch (error) {
            if (this.continueOnFail()) {
                returnData.push({ error: error.message });
            }
            else {
                throw error;
            }
        }
        return [this.helpers.returnJsonArray(returnData)];
    }
}
exports.YahooJpAds = YahooJpAds;
//# sourceMappingURL=YahooJpAds.node.js.map